# axit
Axit means Ax it!  Aims for speedup develop efficient.


# features
- ins()  inspect a variable






# releases

## v0.0.3
- integrate vcs

## v0.0.2
- test new version

## v0.0.1
- born at 2021-01-25